@@ -1,26 +1,19 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2008, Enthought, Inc.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the compound editor factory for all traits toolkit backends.
 """
 
-
-
 from traits.api import Bool, List
 
-from ..editor_factory import EditorFactory
+from traitsui.editor_factory import EditorFactory
 
 # -------------------------------------------------------------------------
 #  Trait definitions:
@@ -29,12 +22,8 @@ from ..editor_factory import EditorFactory
 # List of component editor factories used to build a compound editor
 editors_trait = List(EditorFactory)
 
-# -------------------------------------------------------------------------
-#  'ToolkitEditorFactory' class:
-# -------------------------------------------------------------------------
 
-
-class ToolkitEditorFactory(EditorFactory):
+class CompoundEditor(EditorFactory):
     """ Editor factory for compound editors.
     """
 
@@ -49,5 +38,5 @@ class ToolkitEditorFactory(EditorFactory):
     auto_set = Bool(True)
 
 
-# Define the CompoundEditor class
-CompoundEditor = ToolkitEditorFactory
+# This alias is deprecated and will be removed in TraitsUI 8.
+ToolkitEditorFactory = CompoundEditor
