@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the Group class used to represent a group of items used in a
     Traits-based user interface.
@@ -166,16 +159,27 @@ class Group(ViewSubElement):
     #: the group and its items are not visible (and they disappear if they were
     #: previously visible). If the value evaluates to True, the group and items
     #: become visible. All **visible_when** conditions are checked each time
-    #: that any trait value is edited in the display. Therefore, you can use
-    #: **visible_when** conditions to hide or show groups in response to user
-    #: input.
+    #: that any trait value on an object in the UI's context is changed.
+    #: Therefore, you can use **visible_when** conditions to hide or show
+    #: groups in response to user input. Be aware that this only applies to
+    #: traits in the UI's context. As a result, changes to nested traits that
+    #: don't also change a trait on some object in the context may not
+    #: trigger the expression to be checked. Additionally, the expression needs
+    #: to be a valid python expression given the context. i.e.
+    #: eval(visible_when, globals=globals(), locals=context) should succeed.
     visible_when = Str()
 
     #: Pre-condition for enabling the group. If the expression evaluates to False,
     #: the group is disabled, that is, none of the widgets accept input. All
     #: **enabled_when** conditions are checked each time that any trait value
-    #: is edited in the display. Therefore, you can use **enabled_when**
-    #: conditions to enable or disable groups in response to user input.
+    #: on an object in the UI's context is changed. Therefore, you can use
+    #: **enabled_when** conditions to enable or disable groups in response to
+    #: user input. Be aware that this only applies to traits in the UI's
+    #: context. As a result, changes to nested traits that don't also change a
+    #: trait on some object in the context may not trigger the expression to be
+    #: checked. Additionally, the expression needs to be a valid python
+    #: expression given the context. i.e.
+    #: eval(enabled_when, globals=globals(), locals=context) should succeed.
     enabled_when = Str()
 
     #: Amount of padding (in pixels) to add around each item in the group. The
@@ -186,15 +190,15 @@ class Group(ViewSubElement):
     padding = Padding
 
     #: Requested width of the group (calculated from widths of contents)
-    width = Property(Float, depends_on="content")
+    width = Property(Float, observe="content")
 
     #: Requested height of the group (calculated from heights of contents)
-    height = Property(Float, depends_on="content")
+    height = Property(Float, observe="content")
 
     def __init__(self, *values, **traits):
         """ Initializes the group object.
         """
-        super(ViewSubElement, self).__init__(**traits)
+        super().__init__(**traits)
 
         content = self.content
 
@@ -544,7 +548,7 @@ class ShadowGroup(Group):
         # Set the 'shadow' trait before all others, to avoid exceptions
         # when setting those other traits.
         self.shadow = shadow
-        super(ShadowGroup, self).__init__(**traits)
+        super().__init__(**traits)
 
     # -------------------------------------------------------------------------
     # Trait definitions:
