@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -19,11 +29,6 @@ from pyface.qt import QtGui
 
 from traits.api import Str
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.compound_editor file.
-from traitsui.editors.compound_editor import ToolkitEditorFactory
-
 from .editor import Editor
 
 
@@ -69,7 +74,7 @@ class CompoundEditor(Editor):
         for editor in self._editors:
             editor.dispose()
 
-        super(CompoundEditor, self).dispose()
+        super().dispose()
 
 
 class SimpleEditor(CompoundEditor):
