@@ -1,3 +1,13 @@
+# (C) Copyright 2009-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
@@ -21,11 +31,6 @@ from pyface.qt import QtCore, QtGui
 
 from traits.api import TraitError, Str, Float, Any, Bool
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.range_editor file.
-from traitsui.editors.range_editor import ToolkitEditorFactory
-
 from .editor_factory import TextEditor
 
 from .editor import Editor
@@ -141,7 +146,7 @@ class SimpleSliderEditor(BaseRangeEditor):
 
         # The default size is a bit too big and probably doesn't need to grow.
         sh = text.sizeHint()
-        sh.setWidth(sh.width() / 2)
+        sh.setWidth(sh.width() // 2)
         text.setMaximumSize(sh)
 
         panel.addWidget(text)
@@ -177,7 +182,8 @@ class SimpleSliderEditor(BaseRangeEditor):
     def update_object_on_enter(self):
         """ Handles the user pressing the Enter key in the text field.
         """
-        # it is possible we get the event after the control has gone away
+        # It is possible the event is processed after the control is removed
+        # from the editor
         if self.control is None:
             return
 
@@ -417,7 +423,7 @@ class LargeRangeSliderEditor(BaseRangeEditor):
 
         # The default size is a bit too big and probably doesn't need to grow.
         sh = text.sizeHint()
-        sh.setWidth(sh.width() / 2)
+        sh.setWidth(sh.width() // 2)
         text.setMaximumSize(sh)
 
         panel.addWidget(text)
@@ -449,6 +455,10 @@ class LargeRangeSliderEditor(BaseRangeEditor):
     def update_object_on_enter(self):
         """ Handles the user pressing the Enter key in the text field.
         """
+        # It is possible the event is processed after the control is removed
+        # from the editor
+        if self.control is None:
+            return
         try:
             self.value = eval(str(self.control.text.text()).strip())
         except TraitError as excp:
@@ -719,14 +729,16 @@ class RangeTextEditor(TextEditor):
 # -------------------------------------------------------------------------
 
 
-def SimpleEnumEditor(parent, factory, ui, object, name, description):
+def SimpleEnumEditor(
+    parent, factory, ui, object, name, description, **kwargs
+):
     return CustomEnumEditor(
         parent, factory, ui, object, name, description, "simple"
     )
 
 
 def CustomEnumEditor(
-    parent, factory, ui, object, name, description, style="custom"
+    parent, factory, ui, object, name, description, style="custom", **kwargs
 ):
     """ Factory adapter that returns a enumeration editor of the specified
     style.
