@@ -1,16 +1,12 @@
-# -------------------------------------------------------------------------
-#  Copyright (c) 20011, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 # System library imports
 from pyface.qt import QtCore, QtGui
@@ -28,7 +24,7 @@ class SearchWidget(QtGui.QLineEdit):
     def __init__(self, desc):
         """ Store the descriptive text for the widget.
         """
-        super(SearchWidget, self).__init__()
+        super().__init__()
         self._desc = str(desc)
         self._set_descriptive_text()
 
@@ -45,7 +41,7 @@ class SearchWidget(QtGui.QLineEdit):
             self.setText("")
             self.update()
 
-        super(SearchWidget, self).focusInEvent(event)
+        super().focusInEvent(event)
 
     def focusOutEvent(self, event):
         """ Handles losing focus.
@@ -56,7 +52,7 @@ class SearchWidget(QtGui.QLineEdit):
         if len(self.text()) == 0:
             self._set_descriptive_text()
 
-        super(SearchWidget, self).focusOutEvent(event)
+        super().focusOutEvent(event)
 
     def _set_descriptive_text(self):
         """ Sets the greyed-out descriptive text.
