@@ -1,10 +1,12 @@
-#  Copyright (c) 2019, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 import unittest
 
@@ -12,7 +14,9 @@ from pyface.timer.api import CallbackTimer
 from traits.api import HasTraits, Instance, Int
 from traitsui.api import Handler, Item, UIInfo, View, toolkit
 
-from ._tools import GuiTestAssistant, is_current_backend_qt4, no_gui_test_assistant
+from ._tools import (
+    BaseTestMixin, GuiTestAssistant, is_qt, no_gui_test_assistant
+)
 
 
 class SimpleModel(HasTraits):
@@ -37,19 +41,24 @@ simple_view = View(
 
 
 @unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
-class TestViewApplication(GuiTestAssistant, unittest.TestCase):
+class TestViewApplication(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
     def setUp(self):
+        BaseTestMixin.setUp(self)
         GuiTestAssistant.setUp(self)
         self.model = SimpleModel()
         self.handler = ClosableHandler()
         self.event_loop_timeout = False
         self.closed = False
 
-        if is_current_backend_qt4():
+        if is_qt():
             if len(self.qt_app.topLevelWidgets()) > 0:
                 with self.event_loop_with_timeout(repeat=5):
                     self.gui.invoke_later(self.qt_app.closeAllWindows)
 
+    def tearDown(self):
+        GuiTestAssistant.tearDown(self)
+        BaseTestMixin.tearDown(self)
+
     def view_application(self, kind, button=None):
         if button is None:
             self.gui.invoke_later(self.close_dialog)
@@ -81,14 +90,14 @@ class TestViewApplication(GuiTestAssistant, unittest.TestCase):
             self.gui.invoke_after(100, self.close_dialog)
 
     def close_dialog(self):
-        if is_current_backend_qt4():
+        if is_qt():
             self.handler.info.ui.control.close()
             self.closed = True
         else:
             raise NotImplementedError("Can't close current backend")
 
     def click_button(self, text):
-        if is_current_backend_qt4():
+        if is_qt():
             from pyface.qt.QtGui import QPushButton
             from pyface.ui.qt4.util.testing import find_qt_widget
 
