@@ -1,15 +1,12 @@
-#  Copyright (c) 2005-18, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
+# Thanks for using Enthought open source!
 
 """
 Defines the stub functions used for creating concrete implementations of
@@ -216,8 +213,8 @@ class Toolkit(Toolkit):
         ----------
         context : object or dictionary
             A single object or a dictionary of string/object pairs, whose trait
-            attributes are to be edited. If not specified, the current object is
-            used.
+            attributes are to be edited. If not specified, the current object
+            is used.
         view : view or string
             A View object that defines a user interface for editing trait
             attribute values.
@@ -235,8 +232,8 @@ class Toolkit(Toolkit):
             are saved.
         scrollable : Boolean
             Indicates whether the dialog box should be scrollable. When set to
-            True, scroll bars appear on the dialog box if it is not large enough
-            to display all of the items in the view at one time.
+            True, scroll bars appear on the dialog box if it is not large
+            enough to display all of the items in the view at one time.
 
         """
         raise NotImplementedError(
@@ -341,7 +338,8 @@ class Toolkit(Toolkit):
     def constants(self):
         """ Returns a dictionary of useful constants.
 
-            Currently, the dictionary should have the following key/value pairs:
+            Currently, the dictionary should have the following key/value
+            pairs:
 
             - WindowColor': the standard window background color in the toolkit
               specific color format.
@@ -378,196 +376,3 @@ class Toolkit(Toolkit):
         raise NotImplementedError(
             not_implemented_message.format(ETSConfig.toolkit)
         )
-
-    # -------------------------------------------------------------------------
-    #  'Editor' class methods:
-    # -------------------------------------------------------------------------
-
-    def ui_editor(self):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    # -------------------------------------------------------------------------
-    #  'EditorFactory' factory methods:
-    # -------------------------------------------------------------------------
-
-    def array_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def boolean_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def button_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def check_list_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def code_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def color_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def compound_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def custom_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def directory_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def drop_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def dnd_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def enum_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def file_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def font_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def key_binding_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def history_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def html_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def image_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def image_enum_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def instance_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def list_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def list_str_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def null_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def ordered_set_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def plot_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def range_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def rgb_color_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def rgba_color_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def shell_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def table_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def tabular_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def text_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def title_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def tree_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def tuple_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
-
-    def value_editor(self, *args, **traits):
-        raise NotImplementedError(
-            not_implemented_message.format(ETSConfig.toolkit)
-        )
