@@ -1,26 +1,17 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the UI class used to represent an active traits-based user
     interface.
 """
 
-
-
 import shelve
 import os
 
@@ -38,9 +29,10 @@ from traits.api import (
     Property,
     Str,
     TraitError,
-    on_trait_change,
+    observe,
     property_depends_on,
 )
+from traits.observation.api import trait
 
 from traits.trait_base import traits_home, is_str
 
@@ -248,6 +240,9 @@ class UI(HasPrivateTraits):
     def dispose(self, result=None, abort=False):
         """ Disposes of the contents of a user interface.
         """
+        if self.parent is not None:
+            self.parent.errors -= self.errors
+
         if result is not None:
             self.result = result
 
@@ -275,6 +270,9 @@ class UI(HasPrivateTraits):
     def finish(self):
         """ Finishes disposing of a user interface.
         """
+        # Destroy the control early to silence cascade events when the UI
+        # enters an inconsistent state.
+        toolkit().destroy_control(self.control)
 
         # Reset the contents of the user interface
         self.reset(destroy=False)
@@ -292,7 +290,6 @@ class UI(HasPrivateTraits):
 
         # Destroy the view control:
         self.control._object = None
-        toolkit().destroy_control(self.control)
         self.control = None
 
         # Dispose of any KeyBindings object we reference:
@@ -324,7 +321,7 @@ class UI(HasPrivateTraits):
 
         # Remove any statusbar listeners that have been set up:
         for object, handler, name in self._statusbar:
-            object.on_trait_change(handler, name, remove=True)
+            object.observe(handler, name, remove=True, dispatch="ui")
 
         del self._statusbar[:]
 
@@ -428,7 +425,7 @@ class UI(HasPrivateTraits):
                     object = context.get(prefix[:col])
                     if object is not None:
                         method = getattr(handler, name)
-                        trait_name = prefix[col + 1 :]
+                        trait_name = prefix[col + 1:]
                         self._dispatchers.append(
                             Dispatcher(method, info, object, trait_name)
                         )
@@ -438,10 +435,10 @@ class UI(HasPrivateTraits):
         # If there are any Editor object's whose 'visible', 'enabled' or
         # 'checked' state is controlled by a 'visible_when', 'enabled_when' or
         # 'checked_when' expression, set up an 'anytrait' changed notification
-        # handler on each object in the 'context' that will cause the 'visible',
-        # 'enabled' or 'checked' state of each affected Editor to be set. Also
-        # trigger the evaluation immediately, so the visible, enabled or checked
-        # state of each Editor can be correctly initialized:
+        # handler on each object in the 'context' that will cause the
+        # 'visible', 'enabled' or 'checked' state of each affected Editor to be
+        #  set. Also trigger the evaluation immediately, so the visible,
+        # enabled or checked state of each Editor can be correctly initialized:
         if (len(self._visible) + len(self._enabled) + len(self._checked)) > 0:
             for object in context.values():
                 object.on_trait_change(self._evaluate_when, dispatch="ui")
@@ -867,6 +864,16 @@ class UI(HasPrivateTraits):
 
     # -- Traits Event Handlers ------------------------------------------------
 
+    def _errors_changed(self, name, old, new):
+        if self.parent:
+            self.parent.errors = self.parent.errors - old + new
+
+    def _parent_changed(self, name, old, new):
+        if old is not None:
+            old.errors -= self.errors
+        if new is not None:
+            new.errors += self.errors
+
     def _updated_changed(self):
         if self.rebuild is not None:
             toolkit().rebuild_ui(self)
@@ -879,8 +886,8 @@ class UI(HasPrivateTraits):
         if self.control is not None:
             toolkit().set_icon(self)
 
-    @on_trait_change("parent, view, context")
-    def _pvc_changed(self):
+    @observe("parent, view, context")
+    def _pvc_changed(self, event):
         parent = self.parent
         if (parent is not None) and (self.key_bindings is not None):
             # If we don't have our own history, use our parent's:
