@@ -1,19 +1,12 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   05/20/2005
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the key binding editor for use with the KeyBinding class. This is a
     specialized editor used to associate a particular key with a control (i.e.,
@@ -25,13 +18,6 @@ import wx
 
 from traits.api import Bool, Event
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.key_binding_editor file.
-from traitsui.editors.key_binding_editor import (
-    KeyBindingEditor as ToolkitEditorFactory,
-)
-
 from pyface.wx.dialog import confirmation
 
 from .editor import Editor
@@ -128,7 +114,7 @@ class KeyBindingCtrl(wx.Window):
         size=wx.DefaultSize,
     ):
 
-        super(KeyBindingCtrl, self).__init__(
+        super().__init__(
             parent, wid, pos, size, style=wx.CLIP_CHILDREN | wx.WANTS_CHARS
         )
         # Save the reference to the controlling editor object:
